@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for ds service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.ds import (
+
+    from mypy_boto3_ds import DirectoryServiceClient
+    from mypy_boto3_ds.paginator import (
         DescribeDirectoriesPaginator,
         DescribeDomainControllersPaginator,
         DescribeSharedDirectoriesPaginator,
@@ -27,10 +31,12 @@ Usage::
     list_log_subscriptions_paginator: ListLogSubscriptionsPaginator = client.get_paginator("list_log_subscriptions")
     list_schema_extensions_paginator: ListSchemaExtensionsPaginator = client.get_paginator("list_schema_extensions")
     list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_ds.type_defs import (
     DescribeDirectoriesResultTypeDef,
     DescribeDomainControllersResultTypeDef,
@@ -44,7 +50,6 @@ from mypy_boto3_ds.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = (
     "DescribeDirectoriesPaginator",
     "DescribeDomainControllersPaginator",
@@ -60,20 +65,20 @@ __all__ = (
 
 class DescribeDirectoriesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDirectories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.DescribeDirectories)
+    [Paginator.DescribeDirectories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.DescribeDirectories)
     """
 
     def paginate(
         self, DirectoryIds: List[str] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[DescribeDirectoriesResultTypeDef]:
         """
-        [DescribeDirectories.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.DescribeDirectories.paginate)
+        [DescribeDirectories.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.DescribeDirectories.paginate)
         """
 
 
 class DescribeDomainControllersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDomainControllers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.DescribeDomainControllers)
+    [Paginator.DescribeDomainControllers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.DescribeDomainControllers)
     """
 
     def paginate(
@@ -83,13 +88,13 @@ class DescribeDomainControllersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeDomainControllersResultTypeDef]:
         """
-        [DescribeDomainControllers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.DescribeDomainControllers.paginate)
+        [DescribeDomainControllers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.DescribeDomainControllers.paginate)
         """
 
 
 class DescribeSharedDirectoriesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeSharedDirectories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.DescribeSharedDirectories)
+    [Paginator.DescribeSharedDirectories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.DescribeSharedDirectories)
     """
 
     def paginate(
@@ -99,13 +104,13 @@ class DescribeSharedDirectoriesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeSharedDirectoriesResultTypeDef]:
         """
-        [DescribeSharedDirectories.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.DescribeSharedDirectories.paginate)
+        [DescribeSharedDirectories.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.DescribeSharedDirectories.paginate)
         """
 
 
 class DescribeSnapshotsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.DescribeSnapshots)
+    [Paginator.DescribeSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.DescribeSnapshots)
     """
 
     def paginate(
@@ -115,13 +120,13 @@ class DescribeSnapshotsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeSnapshotsResultTypeDef]:
         """
-        [DescribeSnapshots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.DescribeSnapshots.paginate)
+        [DescribeSnapshots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.DescribeSnapshots.paginate)
         """
 
 
 class DescribeTrustsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeTrusts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.DescribeTrusts)
+    [Paginator.DescribeTrusts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.DescribeTrusts)
     """
 
     def paginate(
@@ -131,57 +136,57 @@ class DescribeTrustsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeTrustsResultTypeDef]:
         """
-        [DescribeTrusts.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.DescribeTrusts.paginate)
+        [DescribeTrusts.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.DescribeTrusts.paginate)
         """
 
 
 class ListIpRoutesPaginator(Boto3Paginator):
     """
-    [Paginator.ListIpRoutes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.ListIpRoutes)
+    [Paginator.ListIpRoutes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.ListIpRoutes)
     """
 
     def paginate(
         self, DirectoryId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListIpRoutesResultTypeDef]:
         """
-        [ListIpRoutes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.ListIpRoutes.paginate)
+        [ListIpRoutes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.ListIpRoutes.paginate)
         """
 
 
 class ListLogSubscriptionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListLogSubscriptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.ListLogSubscriptions)
+    [Paginator.ListLogSubscriptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.ListLogSubscriptions)
     """
 
     def paginate(
         self, DirectoryId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListLogSubscriptionsResultTypeDef]:
         """
-        [ListLogSubscriptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.ListLogSubscriptions.paginate)
+        [ListLogSubscriptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.ListLogSubscriptions.paginate)
         """
 
 
 class ListSchemaExtensionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSchemaExtensions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.ListSchemaExtensions)
+    [Paginator.ListSchemaExtensions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.ListSchemaExtensions)
     """
 
     def paginate(
         self, DirectoryId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListSchemaExtensionsResultTypeDef]:
         """
-        [ListSchemaExtensions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.ListSchemaExtensions.paginate)
+        [ListSchemaExtensions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.ListSchemaExtensions.paginate)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.ListTagsForResource)
+    [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.ListTagsForResource)
     """
 
     def paginate(
         self, ResourceId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTagsForResourceResultTypeDef]:
         """
-        [ListTagsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ds.html#DirectoryService.Paginator.ListTagsForResource.paginate)
+        [ListTagsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/ds.html#DirectoryService.Paginator.ListTagsForResource.paginate)
         """
